# Generated by roxygen2: do not edit by hand

S3method(.GTAPv7_header,ESBC)
S3method(.GTAPv7_header,ESBG)
S3method(.GTAPv7_header,ESBI)
S3method(.GTAPv7_header,ESBQ)
S3method(.GTAPv7_header,ESBS)
S3method(.GTAPv7_header,ETRQ)
S3method(.GTAPv7_header,ISEP)
S3method(.GTAPv7_header,TVOM)
S3method(.GTAPv7_header,VDFA)
S3method(.GTAPv7_header,VDFM)
S3method(.GTAPv7_header,VIFA)
S3method(.GTAPv7_header,VIFM)
S3method(.GTAPv7_header,default)
S3method(.aggregate_data,dat)
S3method(.aggregate_data,par)
S3method(.aggregate_data,set)
S3method(.check_set_map,internal)
S3method(.check_set_map,user)
S3method(.check_shock,custom)
S3method(.check_shock,scenario)
S3method(.check_shock,uniform)
S3method(.check_swap,character)
S3method(.check_swap,full)
S3method(.check_swap,list)
S3method(.check_swap,partial)
S3method(.construct_shock,custom)
S3method(.construct_shock,scenario)
S3method(.construct_shock,uniform)
S3method(.convert_data,GTAPv6)
S3method(.convert_data,GTAPv7)
S3method(.convert_invest_v,GTAPv6)
S3method(.convert_invest_v,GTAPv7)
S3method(.ems_write,closure)
S3method(.ems_write,cmf)
S3method(.ems_write,default)
S3method(.ems_write,list)
S3method(.ems_write,set)
S3method(.ems_write,shock)
S3method(.ems_write,tab)
S3method(.exp_cls_entry,ele)
S3method(.exp_cls_entry,full)
S3method(.exp_cls_entry,mixed)
S3method(.exp_cls_entry,subset)
S3method(.finalize_shocks,"NULL")
S3method(.finalize_shocks,character)
S3method(.finalize_shocks,default)
S3method(.header2GTAPv6,EVFB)
S3method(.header2GTAPv6,EVFP)
S3method(.header2GTAPv6,EVOS)
S3method(.header2GTAPv6,FBEP)
S3method(.header2GTAPv6,FTRV)
S3method(.header2GTAPv6,ISEP)
S3method(.header2GTAPv6,VDFB)
S3method(.header2GTAPv6,VDFP)
S3method(.header2GTAPv6,VMFB)
S3method(.header2GTAPv6,VMFP)
S3method(.header2GTAPv6,dat)
S3method(.header2GTAPv6,default)
S3method(.header2GTAPv6,par)
S3method(.header2GTAPv6,set)
S3method(.header2GTAPv7,ESBD)
S3method(.header2GTAPv7,ESBM)
S3method(.header2GTAPv7,ESBT)
S3method(.header2GTAPv7,ESBV)
S3method(.header2GTAPv7,ETRE)
S3method(.header2GTAPv7,EVFA)
S3method(.header2GTAPv7,EVOA)
S3method(.header2GTAPv7,FBEP)
S3method(.header2GTAPv7,FTRV)
S3method(.header2GTAPv7,ISEP)
S3method(.header2GTAPv7,VDFA)
S3method(.header2GTAPv7,VDFM)
S3method(.header2GTAPv7,VFM)
S3method(.header2GTAPv7,VIFA)
S3method(.header2GTAPv7,VIFM)
S3method(.header2GTAPv7,default)
S3method(.inject_value,data.frame_formula)
S3method(.inject_value,data.frame_read)
S3method(.inject_value,default)
S3method(.inject_value,numeric)
S3method(.names_rename,default)
S3method(.names_rename,set)
S3method(.read_input,csv)
S3method(.read_input,har)
S3method(.reduce2sets,default)
S3method(.reduce2sets,ele)
S3method(.shock_preload,character)
S3method(.shock_preload,data.frame)
S3method(.swap_out,default)
S3method(.swap_out,full)
S3method(.tab_mod,data.frame)
S3method(.tab_mod,numeric_formula)
S3method(.tab_mod,numeric_read)
S3method(.validate_shock,default)
S3method(.validate_shock,uniform)
S3method(.write_shock,custom)
S3method(.write_shock,ele)
S3method(.write_shock,full)
S3method(.write_shock,logical)
S3method(.write_shock,uniform)
S3method(.write_shock,user)
S3method(.year2time_set,default)
S3method(.year2time_set,uniform)
S3method(`[`,ems_data)
export(GTAP_convert)
export(ems_compose)
export(ems_custom_shock)
export(ems_data)
export(ems_deploy)
export(ems_example)
export(ems_model)
export(ems_option_get)
export(ems_option_reset)
export(ems_option_set)
export(ems_scenario_shock)
export(ems_solve)
export(ems_swap)
export(ems_uniform_shock)
export(solve_in_situ)
importFrom(R6,R6Class)
importFrom(cli,ansi_strip)
importFrom(cli,cli_abort)
importFrom(cli,cli_alert_warning)
importFrom(cli,cli_dl)
importFrom(cli,cli_fmt)
importFrom(cli,cli_format)
importFrom(cli,cli_h1)
importFrom(cli,cli_h2)
importFrom(cli,cli_inform)
importFrom(cli,cli_ol)
importFrom(cli,cli_text)
importFrom(cli,cli_ul)
importFrom(cli,cli_verbatim)
importFrom(cli,cli_warn)
importFrom(data.table,.N)
importFrom(data.table,.SD)
importFrom(data.table,CJ)
importFrom(data.table,`:=`)
importFrom(data.table,as.data.table)
importFrom(data.table,copy)
importFrom(data.table,data.table)
importFrom(data.table,dcast)
importFrom(data.table,fintersect)
importFrom(data.table,fread)
importFrom(data.table,fsetdiff)
importFrom(data.table,fsetequal)
importFrom(data.table,funion)
importFrom(data.table,fwrite)
importFrom(data.table,is.data.table)
importFrom(data.table,let)
importFrom(data.table,rbindlist)
importFrom(data.table,set)
importFrom(data.table,setDT)
importFrom(data.table,setattr)
importFrom(data.table,setcolorder)
importFrom(data.table,setkey)
importFrom(data.table,setkeyv)
importFrom(data.table,setnames)
importFrom(data.table,setorder)
importFrom(data.table,setorderv)
importFrom(data.table,uniqueN)
importFrom(purrr,compact)
importFrom(purrr,list_flatten)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map2_chr)
importFrom(purrr,map2_lgl)
importFrom(purrr,map_chr)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
importFrom(purrr,pluck)
importFrom(purrr,pmap)
importFrom(purrr,pmap_chr)
importFrom(purrr,pwalk)
importFrom(purrr,simplify)
importFrom(purrr,transpose)
importFrom(purrr,walk2)
importFrom(rlang,arg_match)
importFrom(rlang,caller_env)
importFrom(rlang,cnd_signal)
importFrom(rlang,current_env)
importFrom(rlang,fn_env)
importFrom(rlang,is_integerish)
importFrom(rlang,trace_back)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(tibble,add_column)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tools,R_user_dir)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(tools,toTitleCase)
importFrom(utils,URLencode)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
importFrom(utils,tail)
importFrom(utils,type.convert)
useDynLib(teems, .registration = TRUE)
