# 3D variable (afeall: ENDWe x ACTSa x REGr), 2 dims fixed
# reduce_shock picks free_idx=[REGr] (k=1)
# write_ragged: single-column branch

dat <- ems_data(
  dat_input = dat_input,
  par_input = par_input,
  set_input = set_input,
  REG = "big3",
  ACTS = "macro_sector",
  ENDW = "labor_agg"
)

model <- ems_model(
  model_file = model_file,
  closure_file = closure_file
)

REG <- c("chn", "usa", "row")
ENDW <- c("labor", "capital", "natlres", "land")
ACTS <- c("svces", "food", "crops", "mnfcs", "livestock")

set.seed(42)

afeall_full <- expand.grid(
  ENDWe = ENDW,
  ACTSa = ACTS,
  REGr = REG,
  stringsAsFactors = FALSE
)
afeall_full$Value <- 0
afeall_full <- afeall_full[do.call(order, afeall_full), ]

# Fix ENDWe="labor" AND ACTSa="crops"; free dim is REGr(3), n=3
# reduce_shock: free_idx=[REGr], k=1
afeall <- afeall_full[
  afeall_full$ENDWe == "labor" & afeall_full$ACTSa == "crops",
]
afeall$Value <- runif(nrow(afeall))

afeall_shk <- ems_custom_shock(var = "afeall", input = afeall)


cmf_path <- ems_deploy(
  .data = dat,
  model = model,
  shock = afeall_shk
)

outputs <- ems_solve(
  cmf_path = cmf_path,
  matrix_method = "LU",
  solution_method = "Johansen"
)

# checks
afeall <- merge(afeall, afeall_full, by = setdiff(colnames(afeall), "Value"), all.y = TRUE)
afeall$Value.x <- ifelse(is.na(afeall$Value.x), afeall$Value.y, afeall$Value.x)
afeall <- afeall[, seq_len(ncol(afeall) - 1)]
colnames(afeall)[ncol(afeall)] <- "Value"

check <- all.equal(afeall, outputs$dat$afeall, check.attributes = FALSE, tolerance = 1e-6)
